@@ -1,5 +1,5 @@
 package Consul;
-$Consul::VERSION = '0.012';
+$Consul::VERSION = '0.013';
 # ABSTRACT: Client library for consul
 
 use namespace::autoclean;
@@ -65,14 +65,6 @@ sub _prep_request {
 sub _prep_response {
     my ($self, $resp, %args) = @_;
 
-    my $valid_cb = $args{_valid_cb} || sub { int($resp->status/100) == 2 };
-
-    unless ($valid_cb->($resp->status)) {
-        my $content = $resp->content || "[no content]";
-        $self->error_cb->(sprintf("%s %s: %s", $resp->status, $resp->reason, $content), $resp);
-        return;
-    }
-
     my $data;
     $data = $json->decode($resp->content) if length $resp->content > 0;
 
@@ -116,7 +108,17 @@ sub _api_exec {
     my $cli_cb = delete $args{cb} || sub { @r = @_ };
 
     $self->request_cb->($self, $self->_prep_request($path, $method, %args, sub {
-        my ($data, $meta) = $self->_prep_response(@_, %args);
+        my ($resp) = @_;
+
+        my $valid_cb = $args{_valid_cb} || sub { int($resp->status/100) == 2 };
+
+        unless ($valid_cb->($resp->status)) {
+            my $content = $resp->content || "[no content]";
+            $self->error_cb->(sprintf("%s %s: %s", $resp->status, $resp->reason, $content), $resp);
+            return;
+        }
+
+        my ($data, $meta) = $self->_prep_response(@_);
         $cli_cb->($resp_cb->($data), $meta);
     }));
 
@@ -459,11 +461,7 @@ See the Consul API docs for more information.
 
 =item *
 
-L<HTTP::Tiny> - for further HTTP client configuration, especially SSL configuration
-
-=item *
-
-L<AnyEvent::Consul> - a wrapper provided asynchronous operation
+L<AnyEvent::Consul> - a wrapper providing asynchronous operation
 
 =item *
 
@@ -476,7 +474,7 @@ L<https://www.consul.io/docs/agent/http.html> - Consul HTTP API documentation
 =head2 Bugs / Feature Requests
 
 Please report any bugs or feature requests through the issue tracker
-at L<https://github.com/robn/p5-consul/issues>.
+at L<https://github.com/robn/Consul/issues>.
 You will be notified automatically of any progress on your issue.
 
 =head2 Source Code
@@ -484,9 +482,9 @@ You will be notified automatically of any progress on your issue.
 This is open source software. The code repository is available for
 public review and contribution under the terms of the license.
 
-L<https://github.com/robn/p5-consul>
+L<https://github.com/robn/Consul>
 
-  git clone https://github.com/robn/p5-consul.git
+  git clone https://github.com/robn/Consul.git
 
 =head1 AUTHORS
 
